==> zio-aws-codecatalyst_2.12-5.19.8.3-sources.jar: zio/aws/codecatalyst/model/package.scala <==
package zio.aws.codecatalyst
import zio.prelude.Subtype
import zio.aws.codecatalyst.model.primitives.ExecuteCommandSessionConfigurationArgumentsMemberString
import java.time.Instant
import zio.aws.codecatalyst.model.primitives.ClientToken.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AccessTokenId extends Subtype[String]
    type AccessTokenId =
      zio.aws.codecatalyst.model.primitives.AccessTokenId.Type
    object AccessTokenName extends Subtype[String]
    type AccessTokenName =
      zio.aws.codecatalyst.model.primitives.AccessTokenName.Type
    object AccessTokenSecret extends Subtype[String]
    type AccessTokenSecret =
      zio.aws.codecatalyst.model.primitives.AccessTokenSecret.Type
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.codecatalyst.model.primitives.ClientToken.Type
    object CreateDevEnvironmentRequestAliasString extends Subtype[String]
    type CreateDevEnvironmentRequestAliasString =
      zio.aws.codecatalyst.model.primitives.CreateDevEnvironmentRequestAliasString.Type
    object DevEnvironmentSummaryAliasString extends Subtype[String]
    type DevEnvironmentSummaryAliasString =
      zio.aws.codecatalyst.model.primitives.DevEnvironmentSummaryAliasString.Type
    object DevEnvironmentSummaryCreatorIdString extends Subtype[String]
    type DevEnvironmentSummaryCreatorIdString =
      zio.aws.codecatalyst.model.primitives.DevEnvironmentSummaryCreatorIdString.Type
    object ExecuteCommandSessionConfigurationArgumentsMemberString
        extends Subtype[String]
    type ExecuteCommandSessionConfigurationArgumentsMemberString =
      zio.aws.codecatalyst.model.primitives.ExecuteCommandSessionConfigurationArgumentsMemberString.Type
    object ExecuteCommandSessionConfigurationCommandString
        extends Subtype[String]
    type ExecuteCommandSessionConfigurationCommandString =
      zio.aws.codecatalyst.model.primitives.ExecuteCommandSessionConfigurationCommandString.Type
    object GetDevEnvironmentResponseAliasString extends Subtype[String]
    type GetDevEnvironmentResponseAliasString =
      zio.aws.codecatalyst.model.primitives.GetDevEnvironmentResponseAliasString.Type
    object GetDevEnvironmentResponseCreatorIdString extends Subtype[String]
    type GetDevEnvironmentResponseCreatorIdString =
      zio.aws.codecatalyst.model.primitives.GetDevEnvironmentResponseCreatorIdString.Type
    object GetUserDetailsRequestIdString extends Subtype[String]
    type GetUserDetailsRequestIdString =
      zio.aws.codecatalyst.model.primitives.GetUserDetailsRequestIdString.Type
    object GetUserDetailsRequestUserNameString extends Subtype[String]
    type GetUserDetailsRequestUserNameString =
      zio.aws.codecatalyst.model.primitives.GetUserDetailsRequestUserNameString.Type
    object IdeConfigurationNameString extends Subtype[String]
    type IdeConfigurationNameString =
      zio.aws.codecatalyst.model.primitives.IdeConfigurationNameString.Type
    object IdeConfigurationRuntimeString extends Subtype[String]
    type IdeConfigurationRuntimeString =
      zio.aws.codecatalyst.model.primitives.IdeConfigurationRuntimeString.Type
    object IdeNameString extends Subtype[String]
    type IdeNameString =
      zio.aws.codecatalyst.model.primitives.IdeNameString.Type
    object IdeRuntimeString extends Subtype[String]
    type IdeRuntimeString =
      zio.aws.codecatalyst.model.primitives.IdeRuntimeString.Type
    object InactivityTimeoutMinutes extends Subtype[Int]
    type InactivityTimeoutMinutes =
      zio.aws.codecatalyst.model.primitives.InactivityTimeoutMinutes.Type
    object ListAccessTokensRequestMaxResultsInteger extends Subtype[Int]
    type ListAccessTokensRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListAccessTokensRequestMaxResultsInteger.Type
    object ListAccessTokensRequestNextTokenString extends Subtype[String]
    type ListAccessTokensRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListAccessTokensRequestNextTokenString.Type
    object ListDevEnvironmentsRequestMaxResultsInteger extends Subtype[Int]
    type ListDevEnvironmentsRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListDevEnvironmentsRequestMaxResultsInteger.Type
    object ListDevEnvironmentsRequestNextTokenString extends Subtype[String]
    type ListDevEnvironmentsRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListDevEnvironmentsRequestNextTokenString.Type
    object ListEventLogsRequestMaxResultsInteger extends Subtype[Int]
    type ListEventLogsRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListEventLogsRequestMaxResultsInteger.Type
    object ListEventLogsRequestNextTokenString extends Subtype[String]
    type ListEventLogsRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListEventLogsRequestNextTokenString.Type
    object ListProjectsRequestMaxResultsInteger extends Subtype[Int]
    type ListProjectsRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListProjectsRequestMaxResultsInteger.Type
    object ListProjectsRequestNextTokenString extends Subtype[String]
    type ListProjectsRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListProjectsRequestNextTokenString.Type
    object ListSourceRepositoriesRequestMaxResultsInteger extends Subtype[Int]
    type ListSourceRepositoriesRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoriesRequestMaxResultsInteger.Type
    object ListSourceRepositoriesRequestNextTokenString extends Subtype[String]
    type ListSourceRepositoriesRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoriesRequestNextTokenString.Type
    object ListSourceRepositoryBranchesRequestMaxResultsInteger
        extends Subtype[Int]
    type ListSourceRepositoryBranchesRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoryBranchesRequestMaxResultsInteger.Type
    object ListSourceRepositoryBranchesRequestNextTokenString
        extends Subtype[String]
    type ListSourceRepositoryBranchesRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoryBranchesRequestNextTokenString.Type
    object ListSpacesRequestNextTokenString extends Subtype[String]
    type ListSpacesRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListSpacesRequestNextTokenString.Type
    object NameString extends Subtype[String]
    type NameString = zio.aws.codecatalyst.model.primitives.NameString.Type
    object PersistentStorageConfigurationSizeInGiBInteger extends Subtype[Int]
    type PersistentStorageConfigurationSizeInGiBInteger =
      zio.aws.codecatalyst.model.primitives.PersistentStorageConfigurationSizeInGiBInteger.Type
    object PersistentStorageSizeInGiBInteger extends Subtype[Int]
    type PersistentStorageSizeInGiBInteger =
      zio.aws.codecatalyst.model.primitives.PersistentStorageSizeInGiBInteger.Type
    object ProjectDescription extends Subtype[String]
    type ProjectDescription =
      zio.aws.codecatalyst.model.primitives.ProjectDescription.Type
    object ProjectDisplayName extends Subtype[String]
    type ProjectDisplayName =
      zio.aws.codecatalyst.model.primitives.ProjectDisplayName.Type
    object RegionString extends Subtype[String]
    type RegionString = zio.aws.codecatalyst.model.primitives.RegionString.Type
    object SensitiveString extends Subtype[String]
    type SensitiveString =
      zio.aws.codecatalyst.model.primitives.SensitiveString.Type
    object SourceRepositoryBranchRefString extends Subtype[String]
    type SourceRepositoryBranchRefString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryBranchRefString.Type
    object SourceRepositoryBranchString extends Subtype[String]
    type SourceRepositoryBranchString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryBranchString.Type
    object SourceRepositoryDescriptionString extends Subtype[String]
    type SourceRepositoryDescriptionString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryDescriptionString.Type
    object SourceRepositoryIdString extends Subtype[String]
    type SourceRepositoryIdString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryIdString.Type
    object SourceRepositoryNameString extends Subtype[String]
    type SourceRepositoryNameString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryNameString.Type
    object StartDevEnvironmentSessionResponseSessionIdString
        extends Subtype[String]
    type StartDevEnvironmentSessionResponseSessionIdString =
      zio.aws.codecatalyst.model.primitives.StartDevEnvironmentSessionResponseSessionIdString.Type
    object StatusReason extends Subtype[String]
    type StatusReason = zio.aws.codecatalyst.model.primitives.StatusReason.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.codecatalyst.model.primitives.SyntheticTimestamp_date_time.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.codecatalyst.model.primitives.Timestamp.Type
    object UpdateDevEnvironmentRequestAliasString extends Subtype[String]
    type UpdateDevEnvironmentRequestAliasString =
      zio.aws.codecatalyst.model.primitives.UpdateDevEnvironmentRequestAliasString.Type
    object UpdateDevEnvironmentResponseAliasString extends Subtype[String]
    type UpdateDevEnvironmentResponseAliasString =
      zio.aws.codecatalyst.model.primitives.UpdateDevEnvironmentResponseAliasString.Type
    object Uuid extends Subtype[String]
    type Uuid = zio.aws.codecatalyst.model.primitives.Uuid.Type
    object VerifySessionResponseIdentityString extends Subtype[String]
    type VerifySessionResponseIdentityString =
      zio.aws.codecatalyst.model.primitives.VerifySessionResponseIdentityString.Type
  }
  type AccessTokenSummaries =
    List[zio.aws.codecatalyst.model.AccessTokenSummary]
  type DevEnvironmentRepositorySummaries =
    List[zio.aws.codecatalyst.model.DevEnvironmentRepositorySummary]
  type DevEnvironmentSummaryList =
    List[zio.aws.codecatalyst.model.DevEnvironmentSummary]
  type EventLogEntries = List[zio.aws.codecatalyst.model.EventLogEntry]
  type ExecuteCommandSessionConfigurationArguments =
    List[ExecuteCommandSessionConfigurationArgumentsMemberString]
  type Filters = List[zio.aws.codecatalyst.model.Filter]
  type IdeConfigurationList = List[zio.aws.codecatalyst.model.IdeConfiguration]
  type Ides = List[zio.aws.codecatalyst.model.Ide]
  type ListSourceRepositoriesItems =
    List[zio.aws.codecatalyst.model.ListSourceRepositoriesItem]
  type ListSourceRepositoryBranchesItems =
    List[zio.aws.codecatalyst.model.ListSourceRepositoryBranchesItem]
  type ProjectListFilters = List[zio.aws.codecatalyst.model.ProjectListFilter]
  type ProjectSummaries = List[zio.aws.codecatalyst.model.ProjectSummary]
  type RepositoriesInput = List[zio.aws.codecatalyst.model.RepositoryInput]
  type SpaceSummaries = List[zio.aws.codecatalyst.model.SpaceSummary]
  type StringList = List[String]
}

==> zio-aws-codecatalyst_2.12-6.20.56.2-sources.jar: zio/aws/codecatalyst/model/package.scala <==
package zio.aws.codecatalyst
import zio.prelude.Subtype
import zio.aws.codecatalyst.model.primitives.ExecuteCommandSessionConfigurationArgumentsMemberString
import java.time.Instant
import zio.aws.codecatalyst.model.primitives.ClientToken.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AccessTokenId extends Subtype[String]
    type AccessTokenId =
      zio.aws.codecatalyst.model.primitives.AccessTokenId.Type
    object AccessTokenName extends Subtype[String]
    type AccessTokenName =
      zio.aws.codecatalyst.model.primitives.AccessTokenName.Type
    object AccessTokenSecret extends Subtype[String]
    type AccessTokenSecret =
      zio.aws.codecatalyst.model.primitives.AccessTokenSecret.Type
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.codecatalyst.model.primitives.ClientToken.Type
    object CreateDevEnvironmentRequestAliasString extends Subtype[String]
    type CreateDevEnvironmentRequestAliasString =
      zio.aws.codecatalyst.model.primitives.CreateDevEnvironmentRequestAliasString.Type
    object DevEnvironmentSummaryAliasString extends Subtype[String]
    type DevEnvironmentSummaryAliasString =
      zio.aws.codecatalyst.model.primitives.DevEnvironmentSummaryAliasString.Type
    object DevEnvironmentSummaryCreatorIdString extends Subtype[String]
    type DevEnvironmentSummaryCreatorIdString =
      zio.aws.codecatalyst.model.primitives.DevEnvironmentSummaryCreatorIdString.Type
    object ExecuteCommandSessionConfigurationArgumentsMemberString
        extends Subtype[String]
    type ExecuteCommandSessionConfigurationArgumentsMemberString =
      zio.aws.codecatalyst.model.primitives.ExecuteCommandSessionConfigurationArgumentsMemberString.Type
    object ExecuteCommandSessionConfigurationCommandString
        extends Subtype[String]
    type ExecuteCommandSessionConfigurationCommandString =
      zio.aws.codecatalyst.model.primitives.ExecuteCommandSessionConfigurationCommandString.Type
    object GetDevEnvironmentResponseAliasString extends Subtype[String]
    type GetDevEnvironmentResponseAliasString =
      zio.aws.codecatalyst.model.primitives.GetDevEnvironmentResponseAliasString.Type
    object GetDevEnvironmentResponseCreatorIdString extends Subtype[String]
    type GetDevEnvironmentResponseCreatorIdString =
      zio.aws.codecatalyst.model.primitives.GetDevEnvironmentResponseCreatorIdString.Type
    object GetUserDetailsRequestIdString extends Subtype[String]
    type GetUserDetailsRequestIdString =
      zio.aws.codecatalyst.model.primitives.GetUserDetailsRequestIdString.Type
    object GetUserDetailsRequestUserNameString extends Subtype[String]
    type GetUserDetailsRequestUserNameString =
      zio.aws.codecatalyst.model.primitives.GetUserDetailsRequestUserNameString.Type
    object IdeConfigurationNameString extends Subtype[String]
    type IdeConfigurationNameString =
      zio.aws.codecatalyst.model.primitives.IdeConfigurationNameString.Type
    object IdeConfigurationRuntimeString extends Subtype[String]
    type IdeConfigurationRuntimeString =
      zio.aws.codecatalyst.model.primitives.IdeConfigurationRuntimeString.Type
    object IdeNameString extends Subtype[String]
    type IdeNameString =
      zio.aws.codecatalyst.model.primitives.IdeNameString.Type
    object IdeRuntimeString extends Subtype[String]
    type IdeRuntimeString =
      zio.aws.codecatalyst.model.primitives.IdeRuntimeString.Type
    object InactivityTimeoutMinutes extends Subtype[Int]
    type InactivityTimeoutMinutes =
      zio.aws.codecatalyst.model.primitives.InactivityTimeoutMinutes.Type
    object ListAccessTokensRequestMaxResultsInteger extends Subtype[Int]
    type ListAccessTokensRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListAccessTokensRequestMaxResultsInteger.Type
    object ListAccessTokensRequestNextTokenString extends Subtype[String]
    type ListAccessTokensRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListAccessTokensRequestNextTokenString.Type
    object ListDevEnvironmentsRequestMaxResultsInteger extends Subtype[Int]
    type ListDevEnvironmentsRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListDevEnvironmentsRequestMaxResultsInteger.Type
    object ListDevEnvironmentsRequestNextTokenString extends Subtype[String]
    type ListDevEnvironmentsRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListDevEnvironmentsRequestNextTokenString.Type
    object ListEventLogsRequestMaxResultsInteger extends Subtype[Int]
    type ListEventLogsRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListEventLogsRequestMaxResultsInteger.Type
    object ListEventLogsRequestNextTokenString extends Subtype[String]
    type ListEventLogsRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListEventLogsRequestNextTokenString.Type
    object ListProjectsRequestMaxResultsInteger extends Subtype[Int]
    type ListProjectsRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListProjectsRequestMaxResultsInteger.Type
    object ListProjectsRequestNextTokenString extends Subtype[String]
    type ListProjectsRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListProjectsRequestNextTokenString.Type
    object ListSourceRepositoriesRequestMaxResultsInteger extends Subtype[Int]
    type ListSourceRepositoriesRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoriesRequestMaxResultsInteger.Type
    object ListSourceRepositoriesRequestNextTokenString extends Subtype[String]
    type ListSourceRepositoriesRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoriesRequestNextTokenString.Type
    object ListSourceRepositoryBranchesRequestMaxResultsInteger
        extends Subtype[Int]
    type ListSourceRepositoryBranchesRequestMaxResultsInteger =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoryBranchesRequestMaxResultsInteger.Type
    object ListSourceRepositoryBranchesRequestNextTokenString
        extends Subtype[String]
    type ListSourceRepositoryBranchesRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListSourceRepositoryBranchesRequestNextTokenString.Type
    object ListSpacesRequestNextTokenString extends Subtype[String]
    type ListSpacesRequestNextTokenString =
      zio.aws.codecatalyst.model.primitives.ListSpacesRequestNextTokenString.Type
    object NameString extends Subtype[String]
    type NameString = zio.aws.codecatalyst.model.primitives.NameString.Type
    object PersistentStorageConfigurationSizeInGiBInteger extends Subtype[Int]
    type PersistentStorageConfigurationSizeInGiBInteger =
      zio.aws.codecatalyst.model.primitives.PersistentStorageConfigurationSizeInGiBInteger.Type
    object PersistentStorageSizeInGiBInteger extends Subtype[Int]
    type PersistentStorageSizeInGiBInteger =
      zio.aws.codecatalyst.model.primitives.PersistentStorageSizeInGiBInteger.Type
    object ProjectDescription extends Subtype[String]
    type ProjectDescription =
      zio.aws.codecatalyst.model.primitives.ProjectDescription.Type
    object ProjectDisplayName extends Subtype[String]
    type ProjectDisplayName =
      zio.aws.codecatalyst.model.primitives.ProjectDisplayName.Type
    object RegionString extends Subtype[String]
    type RegionString = zio.aws.codecatalyst.model.primitives.RegionString.Type
    object SensitiveString extends Subtype[String]
    type SensitiveString =
      zio.aws.codecatalyst.model.primitives.SensitiveString.Type
    object SourceRepositoryBranchRefString extends Subtype[String]
    type SourceRepositoryBranchRefString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryBranchRefString.Type
    object SourceRepositoryBranchString extends Subtype[String]
    type SourceRepositoryBranchString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryBranchString.Type
    object SourceRepositoryDescriptionString extends Subtype[String]
    type SourceRepositoryDescriptionString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryDescriptionString.Type
    object SourceRepositoryIdString extends Subtype[String]
    type SourceRepositoryIdString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryIdString.Type
    object SourceRepositoryNameString extends Subtype[String]
    type SourceRepositoryNameString =
      zio.aws.codecatalyst.model.primitives.SourceRepositoryNameString.Type
    object StartDevEnvironmentSessionResponseSessionIdString
        extends Subtype[String]
    type StartDevEnvironmentSessionResponseSessionIdString =
      zio.aws.codecatalyst.model.primitives.StartDevEnvironmentSessionResponseSessionIdString.Type
    object StatusReason extends Subtype[String]
    type StatusReason = zio.aws.codecatalyst.model.primitives.StatusReason.Type
    object StopDevEnvironmentSessionRequestSessionIdString
        extends Subtype[String]
    type StopDevEnvironmentSessionRequestSessionIdString =
      zio.aws.codecatalyst.model.primitives.StopDevEnvironmentSessionRequestSessionIdString.Type
    object StopDevEnvironmentSessionResponseSessionIdString
        extends Subtype[String]
    type StopDevEnvironmentSessionResponseSessionIdString =
      zio.aws.codecatalyst.model.primitives.StopDevEnvironmentSessionResponseSessionIdString.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.codecatalyst.model.primitives.SyntheticTimestamp_date_time.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.codecatalyst.model.primitives.Timestamp.Type
    object UpdateDevEnvironmentRequestAliasString extends Subtype[String]
    type UpdateDevEnvironmentRequestAliasString =
      zio.aws.codecatalyst.model.primitives.UpdateDevEnvironmentRequestAliasString.Type
    object UpdateDevEnvironmentResponseAliasString extends Subtype[String]
    type UpdateDevEnvironmentResponseAliasString =
      zio.aws.codecatalyst.model.primitives.UpdateDevEnvironmentResponseAliasString.Type
    object Uuid extends Subtype[String]
    type Uuid = zio.aws.codecatalyst.model.primitives.Uuid.Type
    object VerifySessionResponseIdentityString extends Subtype[String]
    type VerifySessionResponseIdentityString =
      zio.aws.codecatalyst.model.primitives.VerifySessionResponseIdentityString.Type
  }
  type AccessTokenSummaries =
    List[zio.aws.codecatalyst.model.AccessTokenSummary]
  type DevEnvironmentRepositorySummaries =
    List[zio.aws.codecatalyst.model.DevEnvironmentRepositorySummary]
  type DevEnvironmentSummaryList =
    List[zio.aws.codecatalyst.model.DevEnvironmentSummary]
  type EventLogEntries = List[zio.aws.codecatalyst.model.EventLogEntry]
  type ExecuteCommandSessionConfigurationArguments =
    List[ExecuteCommandSessionConfigurationArgumentsMemberString]
  type Filters = List[zio.aws.codecatalyst.model.Filter]
  type IdeConfigurationList = List[zio.aws.codecatalyst.model.IdeConfiguration]
  type Ides = List[zio.aws.codecatalyst.model.Ide]
  type ListSourceRepositoriesItems =
    List[zio.aws.codecatalyst.model.ListSourceRepositoriesItem]
  type ListSourceRepositoryBranchesItems =
    List[zio.aws.codecatalyst.model.ListSourceRepositoryBranchesItem]
  type ProjectListFilters = List[zio.aws.codecatalyst.model.ProjectListFilter]
  type ProjectSummaries = List[zio.aws.codecatalyst.model.ProjectSummary]
  type RepositoriesInput = List[zio.aws.codecatalyst.model.RepositoryInput]
  type SpaceSummaries = List[zio.aws.codecatalyst.model.SpaceSummary]
  type StringList = List[String]
}
